==> fcitx_4.2.4.1.orig.tar.xz: fcitx-4.2.4.1/src/module/xkb/xkbconfig.c <==
/***************************************************************************
 *   Copyright (C) 2012~2012 by CSSlayer                                   *
 *   wengxt@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#include <fcitx-config/fcitx-config.h>
#include "xkb.h"

CONFIG_BINDING_BEGIN(FcitxXkbConfig);
CONFIG_BINDING_REGISTER("X Keyboard", "OverrideSystemXKBSettings", bOverrideSystemXKBSettings);
CONFIG_BINDING_REGISTER("X Keyboard", "IgnoreInputMethodLayoutRequest", bIgnoreInputMethodLayoutRequest);
CONFIG_BINDING_END();

==> fcitx_4.2.9.6.orig.tar.xz: fcitx-4.2.9.6/src/module/xkb/xkbconfig.c <==
/***************************************************************************
 *   Copyright (C) 2012~2012 by CSSlayer                                   *
 *   wengxt@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#include <fcitx-config/fcitx-config.h>
#include "xkb-internal.h"

CONFIG_BINDING_BEGIN(FcitxXkbConfig);
CONFIG_BINDING_REGISTER("X Keyboard", "OverrideSystemXKBSettings", bOverrideSystemXKBSettings);
CONFIG_BINDING_REGISTER("X Keyboard", "UseFirstKeyboardIMAsDefaultLayout", useFirstKeyboardIMAsDefaultLayout);
CONFIG_BINDING_REGISTER("X Keyboard", "XModmapCommand", xmodmapCommand);
CONFIG_BINDING_REGISTER("X Keyboard", "CustomXModmapScript", customXModmapScript);
CONFIG_BINDING_END();
